/*
 The software in this package is distributed under the GNU General
 Public License version 2 (with a special exception described below).

 A copy of GNU General Public License (GPL) is included in this distribution,
 in the file COPYING.GPL.

 As a special exception, if other files instantiate templates or use macros
 or inline functions from this file, or you compile this file and link it
 with other works to produce a work based on this file, this file
 does not by itself cause the resulting work to be covered
 by the GNU General Public License.

 However the source code for this file must still be made available
 in accordance with section (3) of the GNU General Public License.

 This exception does not invalidate any other reasons why a work based
 on this file might be covered by the GNU General Public License.

 Christian Herdtweck, Intra2net AG 2015
 */

#include "dns/dnsipprotocol.h"

#include <logfunc.hpp>

using I2n::Logger::GlobalLogger;


std::string to_string(const DnsIpProtocol &protocol)
{
    switch (protocol)
    {
        case DNS_IPv4:  return "IPv4"; break;
        case DNS_IPv6:  return "IPv6"; break;
        case DNS_IPALL: return "IPv4/6"; break;
        default: GlobalLogger.warning() << "Unexpected protocol in to_string!";
                 return "Unexpected Protocol"; break;
    }
}

DnsIpProtocol ping2dns_protocol(const PingProtocol& pprot)
{
    switch (pprot)
    {
        case PingProtocol_ICMP:     return DNS_IPv4; break;
        case PingProtocol_ICMPv6:   return DNS_IPv6; break;
        case PingProtocol_TCP:      return DNS_IPv4; break;
        case PingProtocol_TCP_IPv6: return DNS_IPv6; break;
        default:
            GlobalLogger.warning()
                << "Unexpected ping protocol in ping2dns_protocol: "
                << static_cast<int>(pprot);
            return DNS_IPALL;
            break;
    }
}


